% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/survpred_prclmm.R
\name{survpred_prclmm}
\alias{survpred_prclmm}
\title{Compute predictive survival probabilities from PRC-LMM}
\usage{
survpred_prclmm(step2, step3, times = 1)
}
\arguments{
\item{step2}{the output of \code{\link{summarize_lmms}} 
(step 2 of the estimation of the PRC-LMM model)}

\item{step3}{the output of \code{\link{fit_prclmm}}
(step 3 of the estimation of the PRC-LMM model)}

\item{times}{numeric vector with the time points at which
to estimate the time-dependent AUC}
}
\value{
A data frame with the predicted survival probabilities
computed at the supplied time points
}
\description{
This function computes the predictive survival probabilities 
for the PRC-LMM model proposed in Signorelli et al. (2020, in review)
}
\examples{
# generate example data
set.seed(1234)
p = 4 # number of longitudinal predictors
simdata = simulate_prclmm_data(n = 100, p = p, p.relev = 2, 
             seed = 123, t.values = c(0, 0.2, 0.5, 1, 1.5, 2))
             
# step 1 of PRC-LMM: estimate the LMMs
y.names = paste('marker', 1:p, sep = '')
step1 = fit_lmms(y.names = y.names, 
                 fixefs = ~ age, ranefs = ~ age | id, 
                 long.data = simdata$long.data, 
                 surv.data = simdata$surv.data,
                 t.from.base = t.from.base,
                 n.boots = 0)
                 
# step 2 of PRC-LMM: compute the summaries 
# of the longitudinal outcomes
step2 = summarize_lmms(object = step1)

# step 3 of PRC-LMM: fit the penalized Cox models
step3 = fit_prclmm(object = step2, surv.data = simdata$surv.data,
                   baseline.covs = ~ baseline.age,
                   penalty = 'ridge')
                   
# predict survival probabilities at times 1, 2, 3
surv.probs = survpred_prclmm(step2, step3, times = 1:3)
head(surv.probs)
}
\references{
Signorelli, M., Spitali, P., Tsonaka, R. (in review). 
On the prediction of survival outcomes using longitudinal 
and high-dimensional (omic) data.
}
\seealso{
\code{\link{fit_lmms}} (step 1),
\code{\link{summarize_lmms}} (step 2),
\code{\link{fit_prclmm}} (step 3)
}
\author{
Mirko Signorelli
}
